@@ -644,7 +644,7 @@ class GitlabContainerRunner(
             check_type(argname="argument duration", value=duration, expected_type=type_hints["duration"])
         return typing.cast(None, jsii.invoke(self, "expireAfter", [duration]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="defaultRunnerSG")
     def default_runner_sg(self) -> aws_cdk.aws_ec2.ISecurityGroup:
         '''(experimental) The EC2 runner's default SecurityGroup.
@@ -653,7 +653,7 @@ class GitlabContainerRunner(
         '''
         return typing.cast(aws_cdk.aws_ec2.ISecurityGroup, jsii.get(self, "defaultRunnerSG"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="runnerEc2")
     def runner_ec2(self) -> aws_cdk.aws_ec2.IInstance:
         '''(experimental) This represents a Runner EC2 instance , !!! only support On-demand runner instance !!!
@@ -662,7 +662,7 @@ class GitlabContainerRunner(
         '''
         return typing.cast(aws_cdk.aws_ec2.IInstance, jsii.get(self, "runnerEc2"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="runnerRole")
     def runner_role(self) -> aws_cdk.aws_iam.IRole:
         '''(experimental) The IAM role assumed by the Runner instance .
@@ -671,7 +671,7 @@ class GitlabContainerRunner(
         '''
         return typing.cast(aws_cdk.aws_iam.IRole, jsii.get(self, "runnerRole"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="spotFleetInstanceId")
     def spot_fleet_instance_id(self) -> builtins.str:
         '''(experimental) the first instance id in this fleet , !!! only support spotfleet runner !!!
@@ -680,7 +680,7 @@ class GitlabContainerRunner(
         '''
         return typing.cast(builtins.str, jsii.get(self, "spotFleetInstanceId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="spotFleetRequestId")
     def spot_fleet_request_id(self) -> builtins.str:
         '''(experimental) SpotFleetRequestId for this spot fleet , !!! only support spotfleet runner !!!
@@ -689,7 +689,7 @@ class GitlabContainerRunner(
         '''
         return typing.cast(builtins.str, jsii.get(self, "spotFleetRequestId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         '''(experimental) The EC2 runner's vpc.
@@ -770,7 +770,7 @@ class GitlabContainerRunnerProps:
         :stability: experimental
         '''
         if isinstance(vpc_subnet, dict):
-            vpc_subnet = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnet)
+            vpc_subnet = SubnetSelection(**vpc_subnet)
         if __debug__:
             type_hints = typing.get_type_hints(GitlabContainerRunnerProps.__init__)
             check_type(argname="argument gitlabtoken", value=gitlabtoken, expected_type=type_hints["gitlabtoken"])
@@ -1274,7 +1274,7 @@ class GitlabRunnerAutoscaling(
 
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "createUserData", [props]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="autoscalingGroup")
     def autoscaling_group(self) -> aws_cdk.aws_autoscaling.AutoScalingGroup:
         '''(experimental) This represents a Runner Auto Scaling Group.
@@ -1283,7 +1283,7 @@ class GitlabRunnerAutoscaling(
         '''
         return typing.cast(aws_cdk.aws_autoscaling.AutoScalingGroup, jsii.get(self, "autoscalingGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="instanceRole")
     def instance_role(self) -> aws_cdk.aws_iam.IRole:
         '''(experimental) The IAM role assumed by the Runner instance.
@@ -1292,7 +1292,7 @@ class GitlabRunnerAutoscaling(
         '''
         return typing.cast(aws_cdk.aws_iam.IRole, jsii.get(self, "instanceRole"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="securityGroup")
     def security_group(self) -> aws_cdk.aws_ec2.ISecurityGroup:
         '''(experimental) The EC2 runner's default SecurityGroup.
@@ -1301,7 +1301,7 @@ class GitlabRunnerAutoscaling(
         '''
         return typing.cast(aws_cdk.aws_ec2.ISecurityGroup, jsii.get(self, "securityGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="topicAlarm")
     def topic_alarm(self) -> aws_cdk.aws_sns.ITopic:
         '''(experimental) The SNS topic to suscribe alarms for EC2 runner's metrics.
@@ -1310,7 +1310,7 @@ class GitlabRunnerAutoscaling(
         '''
         return typing.cast(aws_cdk.aws_sns.ITopic, jsii.get(self, "topicAlarm"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         '''(experimental) The EC2 runner's VPC.
@@ -1382,7 +1382,7 @@ class GitlabRunnerAutoscalingProps:
         :stability: experimental
         '''
         if isinstance(vpc_subnet, dict):
-            vpc_subnet = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnet)
+            vpc_subnet = SubnetSelection(**vpc_subnet)
         if __debug__:
             type_hints = typing.get_type_hints(GitlabRunnerAutoscalingProps.__init__)
             check_type(argname="argument gitlab_token", value=gitlab_token, expected_type=type_hints["gitlab_token"])
